Overview
========

History
-------

Here, at the *Greek Research and Technology Network*, we have been developing an IaaS cloud management software called **synnefo** (or **+nefo**) that is accessed and managed via an extended OpenStack Compute API v1.1. Synnefo has been deployed in many environments to cover multiple needs. For example, the `~okeanos <http://okeanos.grnet.gr>`_ IaaS service, running in our data centers, is used to offer services for the Greek Research and Academic Community.

From the early start, we needed a simple command-line tool to test the OpenStack API. That's why we developed *kamaki*, which proved to be powerful and intuitive enough, to be used not only for testing purposes but also as a complete Openstack Compute API v1.1 client, able to manage our cloud from the command line.

Once it proved so useful to us, we decided to open the source, so the community can benefit from it, and *kamaki* can benefit from the community too.

Who uses *kamaki*?
------------------

Kamaki is targeted to new and advanced users who need an intuitive managerial console tool to manage a local or remote synnefo cloud installation.

*kamaki* is currently used (i) internally in GRNET by the development team to test the synnefo software, (ii) by the deployment team which operates the ~okeanos service and (iii) by the testers using the ~okeanos service and want to access the service from the command line.

What's more, (iv) *kamaki* clients API is used in synnefo as an API for accessing remote services as well as (v) for building manager tools of various synnefo functions (e.g. image registration).


Contributing and helping out
----------------------------

The *kamaki* development team values your help and depends on community feedback for feature evolution. Any contributions and bug reports will be highly appreciated. Using *kamaki* and sending us feedback is also a good start.


Community & Support
-------------------

For any problems you may bump into while using *kamaki* or for help from the development team please contact us at::

* Users list: synnefo@googlegroups.com
* Developers list: synnefo-devel@googlegroups.com

Bug reports and feedback are also highly appreciated.
